@@ -1,4 +1,4 @@
-# Copyright (C) 2001-2011 by Barry A. Warsaw
+# Copyright (C) 2001-2012 by Barry A. Warsaw
 #
 # This file is part of flufl.bounce
 #
@@ -27,7 +27,7 @@ __all__ = [
 import re
 
 from email.iterators import body_line_iterator
-from zope.interface import implements
+from zope.interface import implementer
 
 from flufl.bounce.interfaces import (
     IBounceDetector, NoFailures, NoTemporaryFailures)
@@ -37,16 +37,16 @@ acre = re.compile(r',\s*(?P<addr>\S+@[^,]+),', re.IGNORECASE)
 
 
 
+@implementer(IBounceDetector)
 class LLNL:
     """LLNL's custom Sendmail bounce message."""
 
-    implements(IBounceDetector)
-
     def process(self, msg):
         """See `IBounceDetector`."""
 
         for line in body_line_iterator(msg):
             mo = acre.search(line)
             if mo:
-                return NoTemporaryFailures, set([mo.group('addr')])
+                address = mo.group('addr').encode('us-ascii')
+                return NoTemporaryFailures, set([address])
         return NoFailures
