@@ -27,14 +27,14 @@ __all__ = [
 import re
 
 from flufl.enum import Enum
-from io import StringIO
+from io import BytesIO
 from zope.interface import implementer
 
 from flufl.bounce.interfaces import (
     IBounceDetector, NoFailures, NoTemporaryFailures)
 
 
-scre = re.compile(r'transcript of session follows', re.IGNORECASE)
+scre = re.compile(br'transcript of session follows', re.IGNORECASE)
 
 
 class ParseState(Enum):
@@ -56,11 +56,11 @@ class Microsoft:
         except IndexError:
             # The message *looked* like a multipart but wasn't.
             return NoFailures
-        data = subpart.get_payload()
+        data = subpart.get_payload(decode=True)
         if isinstance(data, list):
             # The message is a multi-multipart, so not a matching bounce.
             return NoFailures
-        body = StringIO(data)
+        body = BytesIO(data)
         state = ParseState.start
         addresses = set()
         for line in body:
